Gstream class
Properties
- channel ↔ GrpcWebClientChannel
-
getter/setter pair
-
controller
↔ StreamController<
Message> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- socket ↔ WsClient
-
getter/setter pair
- token ↔ String
-
getter/setter pair
- url ↔ String
-
getter/setter pair
Methods
-
connect(
String url, String token) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
String message) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getInstance(
) → Gstream